@@ -406,6 +406,16 @@ class ShipmentMixin(object):
         elements = cls.make_elements(['Code'], args, kwargs)
         return E.Service(*elements)
 
+    @classmethod
+    def invoice_line_total_type(cls, *args, **kwargs):
+        """
+        :param CurrencyCode: CurrencyCode for MonetaryValue
+        :param MonetaryValue: (Required) Invoice Line Total amount for the
+            entire shipment.
+        """
+        elements = cls.make_elements(['MonetaryValue'], args, kwargs)
+        return E.InvoiceLineTotal(*elements)
+
     @classmethod
     def packaging_type(cls, *args, **kwargs):
         """
@@ -662,6 +672,8 @@ class ShipmentConfirm(ShipmentMixin, BaseAPIClient):
         :param ShipTo: ShipTo element generated by :meth:`ship_to_type`
         :param ShipFrom: ShipFrom element generated by :meth:`ship_from_type`
         :param Service: Service element generated by :meth:`service_type`
+        :param InvoiceLineTotal: InvoiceLineTotal element generated by
+            :meth:`invoice_line_total_type`
         :param PaymentInformation: PaymentInformation element generated by
             :meth:`payment_information_type`
         :param ShipmentServiceOptions: ShipmentServiceOptions element generated
